customernotes auch als notes Form Variable(fixmaster)
[kivitendo-erp.git] / SL / IS.pm
index 5b02041..e32827f 100644 (file)
--- a/SL/IS.pm
+++ b/SL/IS.pm
@@ -604,8 +604,8 @@ sub customer_details {
       $ref->{cp_gender} = $contact->cp_gender;
     }
   }
-  # remove id and taxincluded before copy back
-  delete @$ref{qw(id taxincluded)};
+  # remove id,notes (double of customernotes) and taxincluded before copy back
+  delete @$ref{qw(id taxincluded notes)};
 
   @wanted_vars = grep({ $_ } @wanted_vars);
   if (scalar(@wanted_vars) > 0) {